## START: Set by rpmautospec
## (rpmautospec version 0.2.5)
%define autorelease(e:s:pb:) %{?-p:0.}%{lua:
    release_number = 5;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{?dist}
## END: Set by rpmautospec

Name:           earcut-hpp
Summary:        Fast, header-only polygon triangulation 
Version:        2.2.3
Release:        %autorelease

URL:            https://github.com/mapbox/earcut.hpp
License:        ISC

Source0:        %{url}/archive/v%{version}/earcut.hpp-%{version}.tar.gz

# Include headers for everything used in std::
# https://github.com/mapbox/earcut.hpp/pull/96
Patch0:         https://github.com/mapbox/earcut.hpp/pull/96.patch

BuildRequires:  gcc-c++
BuildRequires:  cmake
# Our choice; the default UNIX Makefiles backend would also work
BuildRequires:  ninja-build

# For tests (and benchmarks, if enabled):
BuildRequires:  pkgconfig(opengl)

# A copy of libtess2 (https://github.com/memononen/libtess2) is bundled with
# the tests as a reference implementation.
#
# We do not treat it as a bundled system library (no virtual Provides, for
# example) because it is provably used only in the tests, and does not
# contribute to anything installed in the binary RPM. This is just as well, as
# libtess2 is unmaintained and we would rather not have to package it
# separately.

# No compiled binaries are installed, so this would be empty.
%global debug_package %{nil}

%undefine __cmake_in_source_build

%global common_description %{expand:
A C++ port of earcut.js, a fast, header-only polygon triangulation library.

The library implements a modified ear slicing algorithm, optimized by z-order
curve hashing and extended to handle holes, twisted polygons, degeneracies and
self-intersections in a way that doesn’t guarantee correctness of
triangulation, but attempts to always produce acceptable results for practical
data like geographical shapes.

It’s based on ideas from FIST: Fast Industrial-Strength Triangulation of
Polygons by Martin Held and Triangulation by Ear Clipping by David Eberly.}

%description %{common_description}


%package devel
Summary:        %{summary}

BuildArch:      noarch

# Header-only library
Provides:       %{name}-static = %{version}-%{release}

%description devel %{common_description}


%prep
%autosetup -n earcut.hpp-%{version} -p1
# Increase precision of test output so we can understand any failures:
sed -r -i 's/(setprecision\()6(\))/\116\2/' test/test.cpp

%ifarch aarch64 ppc64le s390x
# With increased format precision in test/test.cpp, as above:
#   > not ok 83 earcut deviation 0.0000000000052002% is not less than
#   > 0.0000000000043556%
# Loosen tolerance for “self_touching” test on certain architectures
# https://github.com/mapbox/earcut.hpp/issues/97
sed -r -i 's/4\.35559[[:digit:]]+e-14/6\.2002e-14/' \
    'test/fixtures/self_touching.cpp'
%endif


%build
# We do want to build the tests, but we have no use for the benchmarks or the
# visualizer program.
%cmake \
    -DEARCUT_BUILD_TESTS:BOOL=ON \
    -DEARCUT_BUILD_BENCH:BOOL=OFF \
    -DEARCUT_BUILD_VIZ:BOOL=OFF \
    -DEARCUT_WARNING_IS_ERROR:BOOL=OFF \
    -GNinja
%cmake_build


%install
# The upstream CMakeLists.txt has no install target; there is only one file to
# copy, so it is easy to do manually.
install -D -t '%{buildroot}%{_includedir}/mapbox' -p -m 0644 \
    'include/mapbox/earcut.hpp'


%check
# The upstream CMakeLists.txt is not configured to run tests via ctest; we run
# the test executable manually.
%{_vpath_builddir}/tests


%files devel
%license LICENSE
%doc CHANGELOG.md
%doc README.md

# All -devel packages for C and C++ libraries from Mapbox should co-own this
# directory.
%dir %{_includedir}/mapbox

%{_includedir}/mapbox/earcut.hpp


%changelog
* Thu Dec 16 2021 Benjamin A. Beasley <code@musicinmybrain.net> 2.2.3-4
- Let the -devel package be noarch

* Tue Oct 26 2021 Benjamin A. Beasley <code@musicinmybrain.net> 2.2.3-3
- Work around missing %%arm64 macro on EPEL8

* Tue Oct 26 2021 Benjamin A. Beasley <code@musicinmybrain.net> 2.2.3-2
- Enforce out-of-source build on EPEL8

* Tue Oct 26 2021 Benjamin A. Beasley <code@musicinmybrain.net> 2.2.3-1
- Initial package (close RHBZ#2006590)
